/*
 * Copyright (c) 2005 Sun Microsystems, Inc.
 * All rights reserved.
 */
package simple.client;

import javax.xml.ws.BindingProvider;
import javax.xml.ws.Holder;
import javax.xml.ws.soap.SOAPBinding;
import javax.xml.namespace.QName;
import java.io.FileInputStream;
import java.io.FileWriter;

/*Junit imports*/
import junit.framework.Assert;
import org.netbeans.junit.NbTestCase;
import org.netbeans.junit.NbTest;
import org.netbeans.junit.NbTestSuite;

import simple.schema.client.*;
//import interopbaseaddress.interop.*;
import simple.server.*;

public class PingServiceClient extends NbTestCase {
	
	public PingServiceClient (String testName) {
        super(testName);
    }

    public static NbTest suite() {
        NbTestSuite suite = new NbTestSuite(PingServiceClient.class);
        suite.setName("scenario XS");
        return suite;
    }

    protected void setUp() {

    }

    protected void tearDown() {

    }

    public static void main (String[] args) {
			junit.textui.TestRunner.run(suite());
	}

	public void testS2S_ScenarioS2 () {
        try {
            PingService11Sign service = new PingService11Sign();
            IPingServiceSign stub = service.getXSIPingServiceSign();

            // use static stubs to override endpoint property of WSDL
            String serviceHost = System.getProperty("endpoint.host");
            String servicePort = System.getProperty("endpoint.port");
            String serviceURLFragment = System.getProperty("service.url");
            String serviceURL =
                "http://" + serviceHost + ":" + servicePort + serviceURLFragment;

            System.out.println("Service URL=" + serviceURL);

            ((BindingProvider)stub).getRequestContext().
                put(javax.xml.ws.BindingProvider.ENDPOINT_ADDRESS_PROPERTY, serviceURL);

            /*stub.ping(new Holder("X10"), new Holder("Sun"), new Holder("Passed!"));*/
            simple.schema.client.PingRequest req = new simple.schema.client.PingRequest();
            Ping ping = new Ping();
            ping.setScenario("XS");
            ping.setOrigin("Sun");
            ping.setText("Testing");
			System.out.println("Sending Scenario, Origin, Text: "+ping.getScenario()+" , "+ping.getOrigin()+" , "+ping.getText());
            req.setPing(ping);
            simple.schema.client.PingResponse pingResponse  = stub.ping(req);
			PingResponseBody pbr = pingResponse.getPingResponse();
			System.out.println("Received Scenario, Origin, Text: "+pbr.getScenario()+" , "+pbr.getOrigin()+" , "+pbr.getText());
			statusOfTestLogger();
        } catch (Exception ex) {
            System.out.println ("Caught Exception: " + ex.getMessage() );
            ex.printStackTrace();
			statusOfTestLogger(ex);
            junit.framework.Assert.fail(ex.getMessage());
        }
    }


	   //Create the output log file indicating status of test: used by xtest to generate report
    public void statusOfTestLogger() {
        String current_dir = System.getProperty("current.dir");
        String testName = System.getProperty("ant.project.name");
        String fileSeparator = System.getProperty("file.separator");
		String scenarioType = System.getProperty("scenarioType");
        String runOutputFilePath = current_dir + fileSeparator + "logs" 
                + fileSeparator + testName + "-"+scenarioType+"-status.txt";
        System.out.println("-------------" + runOutputFilePath + "---------------" );
        try{
            FileWriter fw = new FileWriter(runOutputFilePath);
            String str ="PASSED"+"\n";
            fw.write(str);
            fw.close();
        }catch(Exception ex){
            System.out.println(ex.getMessage());
        }
    }
    
    public void statusOfTestLogger(Exception e) {
        String current_dir = System.getProperty("current.dir");
        String testName = System.getProperty("ant.project.name");
        String fileSeparator = System.getProperty("file.separator");
		String scenarioType = System.getProperty("scenarioType");
        String runOutputFilePath = current_dir + fileSeparator + "logs" 
                + fileSeparator + testName + "-"+scenarioType+"-status.txt";
        System.out.println("-------------" + runOutputFilePath + "---------------" );
        try{
            FileWriter fw = new FileWriter(runOutputFilePath);
            String str ="FAILED"+ "\n" + e.getMessage() + "\n";
            StackTraceElement[] stackTraceArray = e.getStackTrace();
            for(int i=0; i< stackTraceArray.length ; i++) {
               str += stackTraceArray[i].toString()+"\n";
            }
            str += "CHECK Runtime Log for details";
            fw.write(str);
            fw.close();
        }catch(Exception ex){
            System.out.println(ex.getMessage());
        }
    }
}
